Writer

Trait Writer 

pub trait Writer<T: Send + 'static>: Send {
    // Required methods
    fn process_slice(&mut self, slice: &[T]);
    fn flush(&mut self);
}
Writer performs data processing of a fully filled buffer.

Required Methods

fn process_slice(&mut self, slice: &[T])

Logger calls this function when there is data to be processed. This function is guaranteed to be called sequentially; no internal synchronization is required by default.

fn flush(&mut self)

Flush the remining data, and finalize writer. This function is called only on writer thread termination.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors